# Changelog

## 0.0.5 (2026-03-03)

Full Changelog: [v0.0.4...v0.0.5](https://github.com/inconvoai/inconvo-python-sdk/compare/v0.0.4...v0.0.5)

### Chores

* **internal:** codegen related update ([28664e0](https://github.com/inconvoai/inconvo-python-sdk/commit/28664e0045fc13c71ae96f735c13936671ed3c24))

## 0.0.4 (2026-02-27)

Full Changelog: [v0.0.3...v0.0.4](https://github.com/inconvoai/inconvo-python-sdk/compare/v0.0.3...v0.0.4)

### Chores

* **ci:** bump uv version ([64af667](https://github.com/inconvoai/inconvo-python-sdk/commit/64af667ce0c338e611c8967d8ca293801841464e))
* **internal:** make `test_proxy_environment_variables` more resilient to env ([b8c9f6e](https://github.com/inconvoai/inconvo-python-sdk/commit/b8c9f6e9ad78e08c401dfe5804aa4d681a632f98))

## 0.0.3 (2026-02-24)

Full Changelog: [v0.0.2...v0.0.3](https://github.com/inconvoai/inconvo-python-sdk/compare/v0.0.2...v0.0.3)

## 0.0.2 (2026-02-24)

Full Changelog: [v0.0.1...v0.0.2](https://github.com/inconvoai/inconvo-python-sdk/compare/v0.0.1...v0.0.2)

### Chores

* configure new SDK language ([59e23bd](https://github.com/inconvoai/inconvo-python-sdk/commit/59e23bd7c3d27f754e326f173bd42e5f621242fe))
* update SDK settings ([fe2f683](https://github.com/inconvoai/inconvo-python-sdk/commit/fe2f6835bbd60e0ca801060134088c6b05b8d091))
* update SDK settings ([653b243](https://github.com/inconvoai/inconvo-python-sdk/commit/653b243905b8458008f22ea61ec83fff094d15e0))
* update SDK settings ([cb55866](https://github.com/inconvoai/inconvo-python-sdk/commit/cb55866644c26dfd1836a706354e8f9e15f1b470))
